@@ -24,4 +24,5 @@
 #' \item{DB}{Database}
 #' }
 #' @source \url{http://www.scopus.com}
-"scopusCollection"
\ No newline at end of file
+#' @name scopusCollection
+NULL
\ No newline at end of file
